using NAnt.Core;
using NAnt.Core.Attributes;

namespace Nant.VMWare.Tasks
{
    [TaskName( "prepare-vm" )]
    public class PrepareVirtualMachineTask : VirtualMachineTask
    {
        [TaskAttribute( "url", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string FarmUrl { get; set; }

        [TaskAttribute( "login", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string FarmLogin { get; set; }

        [TaskAttribute( "password", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string FarmPassword { get; set; }

        [TaskAttribute( "vm-user", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string User { get; set; }

        [TaskAttribute( "vm-password", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string Password { get; set; }

        [TaskAttribute( "snapshot", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string CleanSnapshotName { get; set; }

        [TaskAttribute( "vm-name", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string VirtualMachineName { get; set; }

        [TaskAttribute( "vm-file-name", Required = false )]
        public string VirtualMachineFileName { get; set; }

        [TaskAttribute( "datastore-name", Required = true )]
        [StringValidator( AllowEmpty = false )]
        public string DataStoreName { get; set; }

        protected override void ExecuteTask()
        {
            VmWareConfiguration config = new VmWareConfiguration
                                             {
                                                 CleanSnapshotName = CleanSnapshotName,
                                                 FarmUrl = FarmUrl,
                                                 FarmLogin = FarmLogin,
                                                 FarmPassword = FarmPassword,
                                                 VirtualMachineName = VirtualMachineName,
                                                 VirtualMachineFileName = VirtualMachineFileName,
                                                 User = User,
                                                 Password = Password,
                                                 DataStoreName = DataStoreName
                                             };
            config.Build();

            Configuration = config;
            Log( Level.Info, "Virtual Machine '{0}' configuration created", VirtualMachineName );
        }
    }
}